import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#e8e55a'])

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['50', '30'])

const xPosition = (d, i) => i * 180 + 100;

export const fruitBowl = (selection, props) =>{
  const { fruits, height, onClick, selectedFruit } = props 
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 138)
      .attr('width', 900)
      .attr('height', 200)
      .attr('rx', 200 / 2);
  const groups = selection.selectAll('g')
  	.data(fruits);
  const groupsEnter = groups.enter().append('g')
  groupsEnter.merge(groups)
    .attr('transform', (d, i) =>
         `translate(${xPosition(d, i)}, ${height / 2})`);
  groups.exit().remove();

  groupsEnter.append('circle')
  		.attr('r', 0)
  	.merge(groups.select('circle'))
  		.attr('stroke-width','5px')
  		.attr('stroke', d => 
           d.id === selectedFruit
           ? 'black'
           : 'none')
  		.on('click', d => onClick(d.id))
  	.transition().duration(1000)
  		.attr('r', d => radiusScale(d.type))
      .attr('fill', d => colorScale(d.type));
  	
  groupsEnter.append('text')
  	.merge(groups.select('text'))
    	.text(d => d.type)
  		.attr('y', 75)
  
  
  const text = selection.selectAll('text')
  	.data(fruits);

  text
    .enter().append('text')
      .attr('x', xPosition)
      .attr('y', height / 2 + 75)
  	.merge(text)
      .text(d => d.type);
  
  
  text.exit().remove();
  
  
}

